/********************************************************************************
** Form generated from reading UI file 'customgame.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMGAME_H
#define UI_CUSTOMGAME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kpluralhandlingspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_CustomGameConfig
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    KPluralHandlingSpinBox *kcfg_CustomWidth;
    QLabel *label_2;
    KPluralHandlingSpinBox *kcfg_CustomHeight;
    QLabel *label_3;
    KPluralHandlingSpinBox *kcfg_CustomMines;
    QSpacerItem *spacerItem;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *CustomGameConfig)
    {
        if (CustomGameConfig->objectName().isEmpty())
            CustomGameConfig->setObjectName("CustomGameConfig");
        CustomGameConfig->resize(316, 241);
        gridLayout = new QGridLayout(CustomGameConfig);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(CustomGameConfig);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        kcfg_CustomWidth = new KPluralHandlingSpinBox(CustomGameConfig);
        kcfg_CustomWidth->setObjectName("kcfg_CustomWidth");

        gridLayout->addWidget(kcfg_CustomWidth, 0, 1, 1, 1);

        label_2 = new QLabel(CustomGameConfig);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        kcfg_CustomHeight = new KPluralHandlingSpinBox(CustomGameConfig);
        kcfg_CustomHeight->setObjectName("kcfg_CustomHeight");

        gridLayout->addWidget(kcfg_CustomHeight, 1, 1, 1, 1);

        label_3 = new QLabel(CustomGameConfig);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        kcfg_CustomMines = new KPluralHandlingSpinBox(CustomGameConfig);
        kcfg_CustomMines->setObjectName("kcfg_CustomMines");

        gridLayout->addWidget(kcfg_CustomMines, 2, 1, 1, 1);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacerItem, 0, 2, 1, 1);

        spacerItem1 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem1, 3, 1, 1, 1);


        retranslateUi(CustomGameConfig);

        QMetaObject::connectSlotsByName(CustomGameConfig);
    } // setupUi

    void retranslateUi(QWidget *CustomGameConfig)
    {
        label->setText(tr2i18n("Width:", nullptr));
        label_2->setText(tr2i18n("Height:", nullptr));
        label_3->setText(tr2i18n("Mines:", nullptr));
        (void)CustomGameConfig;
    } // retranslateUi

};

namespace Ui {
    class CustomGameConfig: public Ui_CustomGameConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMGAME_H

