/********************************************************************************
** Form generated from reading UI file 'generalopts.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALOPTS_H
#define UI_GENERALOPTS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GeneralOptsConfig
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_UseQuestionMarks;
    QCheckBox *kcfg_AllowKminesReset;
    QCheckBox *kcfg_DisableScoreOnReset;
    QCheckBox *kcfg_ExploreWithLeftClickOnNumberCells;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *kcfg_PlaceFlagOn;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GeneralOptsConfig)
    {
        if (GeneralOptsConfig->objectName().isEmpty())
            GeneralOptsConfig->setObjectName("GeneralOptsConfig");
        GeneralOptsConfig->resize(316, 135);
        verticalLayout = new QVBoxLayout(GeneralOptsConfig);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_UseQuestionMarks = new QCheckBox(GeneralOptsConfig);
        kcfg_UseQuestionMarks->setObjectName("kcfg_UseQuestionMarks");

        verticalLayout->addWidget(kcfg_UseQuestionMarks);

        kcfg_AllowKminesReset = new QCheckBox(GeneralOptsConfig);
        kcfg_AllowKminesReset->setObjectName("kcfg_AllowKminesReset");
        kcfg_AllowKminesReset->setChecked(true);
        kcfg_AllowKminesReset->setTristate(false);

        verticalLayout->addWidget(kcfg_AllowKminesReset);

        kcfg_DisableScoreOnReset = new QCheckBox(GeneralOptsConfig);
        kcfg_DisableScoreOnReset->setObjectName("kcfg_DisableScoreOnReset");

        verticalLayout->addWidget(kcfg_DisableScoreOnReset);

        kcfg_ExploreWithLeftClickOnNumberCells = new QCheckBox(GeneralOptsConfig);
        kcfg_ExploreWithLeftClickOnNumberCells->setObjectName("kcfg_ExploreWithLeftClickOnNumberCells");

        verticalLayout->addWidget(kcfg_ExploreWithLeftClickOnNumberCells);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(GeneralOptsConfig);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        kcfg_PlaceFlagOn = new QComboBox(GeneralOptsConfig);
        kcfg_PlaceFlagOn->addItem(QString());
        kcfg_PlaceFlagOn->addItem(QString());
        kcfg_PlaceFlagOn->setObjectName("kcfg_PlaceFlagOn");

        horizontalLayout->addWidget(kcfg_PlaceFlagOn);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(GeneralOptsConfig);

        QMetaObject::connectSlotsByName(GeneralOptsConfig);
    } // setupUi

    void retranslateUi(QWidget *GeneralOptsConfig)
    {
        kcfg_UseQuestionMarks->setText(tr2i18n("Use '?' marks", nullptr));
        kcfg_AllowKminesReset->setText(tr2i18n("Allow KMines reset", nullptr));
        kcfg_DisableScoreOnReset->setText(tr2i18n("Disable score on reset", nullptr));
        kcfg_ExploreWithLeftClickOnNumberCells->setText(tr2i18n("Explore with left click on number cells", nullptr));
        label->setText(tr2i18n("Place flag when mouse button is:", nullptr));
        kcfg_PlaceFlagOn->setItemText(0, tr2i18n("Released", nullptr));
        kcfg_PlaceFlagOn->setItemText(1, tr2i18n("Pressed", nullptr));

        (void)GeneralOptsConfig;
    } // retranslateUi

};

namespace Ui {
    class GeneralOptsConfig: public Ui_GeneralOptsConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALOPTS_H

